core.fixer.FixResult

core.fixer.FixResult(
    fixed=list(),
    would_fix=list(),
    unfixable=list(),
    already_passing=list(),
    errors=list(),
)

Result of running fixes.

Attributes: fixed: List of check IDs that were successfully fixed would_fix: List of check IDs that would be fixed (dry-run mode) unfixable: List of check IDs that cannot be auto-fixed already_passing: List of check IDs that were already passing errors: List of (check_id, error_message) tuples for failed fixes

Attributes

Name Description
total_errors Total number of fix errors.
total_fixed Total number of checks that were fixed.
total_unfixable Total number of checks that cannot be auto-fixed.
total_would_fix Total number of checks that would be fixed (dry-run).