core.fixer.FixRunner

core.fixer.FixRunner(
    path,
    check_registry,
    fixture_registry,
    dry_run=False,
    skip_ids=None,
    skip_groups=None,
    only_ids=None,
    only_groups=None,
)

Orchestrates automatic fixing of check failures.

Attributes: path: Path to the package being fixed check_registry: Registry of available checks fixture_registry: Registry of available fixtures dry_run: If True, only report what would be fixed skip_ids: Check IDs to skip skip_groups: Check groups to skip only_ids: If set, only fix these check IDs only_groups: If set, only fix checks in these groups

Methods

Name Description
fix Run fixes for failed checks.

fix

core.fixer.FixRunner.fix()

Run fixes for failed checks.

Returns: FixResult containing information about fixed, unfixable, and errored checks