core.registry.is_fixable
core.registry.is_fixable(check_class)Check if a check class has a callable fix() method.
Args: check_class: The check class to inspect
Returns: True if the check has a callable fix() method, False otherwise
Check if a check class has a callable fix() method.
Args: check_class: The check class to inspect
Returns: True if the check has a callable fix() method, False otherwise