profiles.apply_profile

profiles.apply_profile(config, profile)

Apply a profile to a configuration, with config taking precedence.

Profile settings are used as defaults. Any explicitly set config values override the profile settings. Severity overrides from the profile are used when the config doesn’t have any.

Args: config: The base configuration (may have explicit overrides) profile: The profile to apply

Returns: A new Config with profile settings applied, config values taking precedence.