CheckStatus
CheckStatus()Status of a check result.
Attributes
| Name | Description |
|---|---|
| counts_toward_total | Return True if this status should be counted in totals. |
| is_failure | Return True if this status represents a failure. |
Status of a check result.
| Name | Description |
|---|---|
| counts_toward_total | Return True if this status should be counted in totals. |
| is_failure | Return True if this status represents a failure. |